@@ -70,7 +70,8 @@ class Client(DatasetMixin, DatasetGroupMixin, ModelMixin, ModelGroupMixin, TaskM
         return clean_nones(self.context.request('POST', '/api/graphql', data=json.dumps({'query': query})).json())
     
     def check_entity_exists(self, urn: str):
-        return self._query_graphql('entityExists', urn=urn)['data']['entityExists']
+        r = self._query_graphql('entityExists', urn=urn)['data']
+        return r.get('entityExists', False)
 
     def _sync_check(self, task, check, *args, **kwargs):
         logger.debug(f'start sync check task : {task}')
