@@ -33,6 +33,8 @@ class DatasetGroupMixin:
         if not self.check_entity_exists(urn):
             return
         r = self._query_graphql(DatasetGroup.entity_type, urn=urn)['data'][DatasetGroup.entity_type]
+        if (r.get('status') or {}).get('removed'):
+            return None
         properties = r.get('properties', {})
         custom_properties = {e['key']: e['value'] for e in properties.get('customProperties', {})}
         display_name = properties.get('name', r.get('name'))
