@@ -50,6 +50,8 @@ class ModelMixin:
         if not self.check_entity_exists(urn):
             return
         r = self._query_graphql(Model.entity_type, urn=urn)['data']['mlModel']
+        if (r.get('status') or {}).get('removed'):
+            return None
         properties = r.get('properties', {})
         custom_properties = {e['key']: e['value'] for e in properties.get('customProperties', {})}
         display_name = custom_properties.pop('display_name', r['name'])
