@@ -37,6 +37,8 @@ class ModelGroupMixin:
         if not self.check_entity_exists(urn):
             return
         r = self._query_graphql(ModelGroup.entity_type, urn=urn)['data'][ModelGroup.entity_type]
+        if (r.get('status') or {}).get('removed'):
+            return None
         properties = r.get('properties', {})
         custom_properties = {e['key']: e['value'] for e in properties.get('customProperties', {})}
         display_name = custom_properties.pop('display_name', r['name'])
